.. Copyright (C) 2020 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2020 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _debops.global_handlers:

debops.global_handlers
======================

.. include:: man_description.rst
   :start-line: 7

.. toctree::
   :maxdepth: 2

   getting-started

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/global_handlers/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
